Struct amazon_sp_finances::models::value_added_service_charge_event_list::ValueAddedServiceChargeEventList
source · [−]pub struct ValueAddedServiceChargeEventList {
pub transaction_type: Option<String>,
pub posted_date: Option<String>,
pub description: Option<String>,
pub transaction_amount: Option<Box<Currency>>,
}Expand description
ValueAddedServiceChargeEventList : An event related to a value added service charge.
Fields
transaction_type: Option<String>Indicates the type of transaction. Example: ‘Other Support Service fees’
posted_date: Option<String>description: Option<String>A short description of the service charge event.
transaction_amount: Option<Box<Currency>>Implementations
sourceimpl ValueAddedServiceChargeEventList
impl ValueAddedServiceChargeEventList
sourcepub fn new() -> ValueAddedServiceChargeEventList
pub fn new() -> ValueAddedServiceChargeEventList
An event related to a value added service charge.